@@ -1,3 +1,8 @@
+import bionetgen as bng
+from bionetgen.modelapi.utils import run_command
+import bionetgen.modelapi.model as mdl
+import os, subprocess
+from tempfile import NamedTemporaryFile
 from bionetgen.tools import BNGPlotter
 from bionetgen.tools import BNGInfo
 from bionetgen.tools import BNGVisualize
@@ -64,10 +69,20 @@ def plotDAT(inp, out=".", kw=dict()):
         fnoext, ext = os.path.splitext(fname)
         out = os.path.join(path, "{}.png".format(fnoext))
     # use the plotter object to get the plot
+    from bionetgen.core import BNGPlotter
+
     plotter = BNGPlotter(inp, out, **kw)
     plotter.plot()
 
 
+def runAtomizeTool(config, args):
+    from bionetgen.atomizer import AtomizeTool
+
+    a = AtomizeTool(parser_namespace=args)
+    # do config specific stuff here if need be, or remove the config requirement
+    a.run()
+
+
 def printInfo(config, args):
     """
     Uses BNGInfo class to print BioNetGen information using
